==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/WebColumnMovingEventArgsDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
var WebColumnMovingEventArgsDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebColumnMovingEventArgsDescription, _super);
    function WebColumnMovingEventArgsDescription() {
        var _this = _super.call(this) || this;
        _this.f = null;
        return _this;
    }
    WebColumnMovingEventArgsDescription.prototype.get_type = function () {
        return "WebColumnMovingEventArgs";
    };
    Object.defineProperty(WebColumnMovingEventArgsDescription.prototype, "type", {
        get: function () {
            return this.get_type();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebColumnMovingEventArgsDescription.prototype, "detail", {
        get: function () {
            return this.f;
        },
        set: function (a) {
            this.f = a;
            this.e("Detail");
        },
        enumerable: true,
        configurable: true
    });
    WebColumnMovingEventArgsDescription.$t = markType(WebColumnMovingEventArgsDescription, 'WebColumnMovingEventArgsDescription', Description.$);
    WebColumnMovingEventArgsDescription.__marshalByValue = true;
    WebColumnMovingEventArgsDescription.__marshalByValueAlias = "ColumnMovingEventArgs";
    return WebColumnMovingEventArgsDescription;
}(Description));
export { WebColumnMovingEventArgsDescription };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/WebColumnMovingEventArgsDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
var WebColumnMovingEventArgsDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebColumnMovingEventArgsDescription, _super);
    function WebColumnMovingEventArgsDescription() {
        var _this = _super.call(this) || this;
        _this.h = null;
        return _this;
    }
    WebColumnMovingEventArgsDescription.prototype.get_type = function () {
        return "WebColumnMovingEventArgs";
    };
    Object.defineProperty(WebColumnMovingEventArgsDescription.prototype, "type", {
        get: function () {
            return this.get_type();
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebColumnMovingEventArgsDescription.prototype, "detail", {
        get: function () {
            return this.h;
        },
        set: function (a) {
            this.h = a;
            this.g("Detail");
        },
        enumerable: false,
        configurable: true
    });
    WebColumnMovingEventArgsDescription.$t = markType(WebColumnMovingEventArgsDescription, 'WebColumnMovingEventArgsDescription', Description.$);
    WebColumnMovingEventArgsDescription.__marshalByValue = true;
    WebColumnMovingEventArgsDescription.__marshalByValueAlias = "ColumnMovingEventArgs";
    return WebColumnMovingEventArgsDescription;
}(Description));
export { WebColumnMovingEventArgsDescription };
